@@ -8,10 +8,11 @@ HOST_NOT_FOUND = 1
 NO_DATA = 4
 
 
-async def _get_fqdns(fqdn: str, protocol: int) -> List[str]:
+async def _get_fqdns(hub, protocol: int) -> List[str]:
+
     try:
         result = socket.getaddrinfo(
-            host=fqdn,
+            host=hub.corn.CORN.fqdn,
             port=None,
             family=protocol,
             proto=socket.IPPROTO_IP,
@@ -56,6 +57,6 @@ async def load_socket_info(hub):
 
     hub.log.debug("loading fqdns based grains")
     hub.corn.CORN.host, hub.corn.CORN.domain = hub.corn.CORN.fqdn.partition(".")[::2]
-    hub.corn.CORN.fqdn_ip4 = await _get_fqdns(hub.corn.CORN.fqdn, socket.AF_INET)
-    hub.corn.CORN.fqdn_ip6 = await _get_fqdns(hub.corn.CORN.fqdn, socket.AF_INET6)
+    hub.corn.CORN.fqdn_ip4 = await _get_fqdns(hub, socket.AF_INET)
+    hub.corn.CORN.fqdn_ip6 = await _get_fqdns(hub, socket.AF_INET6)
     hub.corn.CORN.fqdns = hub.corn.CORN.fqdn_ip4 + hub.corn.CORN.fqdn_ip6
