@@ -4,12 +4,11 @@
 # Salt (i.e. python2 or python3)
 import aiofiles
 import distro
-import logging
+
 import re
 import os
 from typing import Any, Dict
 
-log = logging.getLogger(__name__)
 
 # Matches any possible format:
 #     DISTRIB_ID="Ubuntu"
@@ -37,7 +36,7 @@ async def _parse_lsb_release(hub) -> Dict[str, Any]:
     grains = {}
     if os.path.exists(name):
         try:
-            log.debug("Attempting to parse /etc/lsb-release")
+            hub.log.debug("Attempting to parse /etc/lsb-release")
             async with aiofiles.open(name) as ifile:
                 async for line in ifile:
                     try:
@@ -48,14 +47,14 @@ async def _parse_lsb_release(hub) -> Dict[str, Any]:
                         # Adds lsb_distrib_{id,release,codename,description}
                         grains[f"lsb_{key.lower()}"] = value.rstrip()
         except (IOError, OSError) as exc:
-            log.debug("Failed to parse /etc/lsb-release: %s", exc)
+            hub.log.debug("Failed to parse /etc/lsb-release: %s", exc)
     return grains
 
 
 async def _import_lsb_release(hub) -> Dict[str, Any]:
     grains = {}
     try:
-        log.debug("Getting lsb_release distro information")
+        hub.log.debug("Getting lsb_release distro information")
         import lsb_release  # pylint: disable=import-error
 
         release = lsb_release.get_distro_information()
