@@ -1,23 +1,16 @@
-import pop.hub
 import pytest
-import sys
-import unittest.mock as mock
 
 
 @pytest.fixture(scope="session")
-def hub():
+def hub(base_hub):
     """
     provides a full hub that is used as a reference for mock_hub
     """
-    hub = pop.hub.Hub()
+    base_hub.pop.sub.add(dyne_name="corn")
+    base_hub.pop.sub.add(dyne_name="exec")
+    base_hub.pop.sub.add(dyne_name="states")
 
-    # strip pytest args
-    with mock.patch.object(sys, "argv", sys.argv[:1]):
-        hub.pop.sub.add(dyne_name="corn")
-        hub.pop.sub.add(dyne_name="exec")
-        hub.pop.sub.add(dyne_name="states")
-
-    return hub
+    return base_hub
 
 
 @pytest.fixture(scope="function")
